# Notifier Bot

Notifier Bot is a Python library consisting of different Notification Bots


## Available Bots

- Telegram Bot

## Setup

### Telegram Bot

1. Refer to this [link](https://www.section.io/engineering-education/building-a-telegram-bot-with-python-to-generate-quotes/) to create a Telegram Bot and get the `BOT_TOKEN` and `CHAT_ID`.

2. Use the `BOT_TOKEN` and `CHAT_ID` to initialize `TelegramConfig` object.

3. Use the `TelegramConfig` object to initialize `TelegramBot`.

## Examples

Refer to [examples](examples) directory
